@@ -1,7 +1,7 @@
 package Web::Query;
 our $AUTHORITY = 'cpan:TOKUHIROM';
 # ABSTRACT: Yet another scraping library like jQuery
-$Web::Query::VERSION = '0.33';
+$Web::Query::VERSION = '0.34';
 use strict;
 use warnings;
 use 5.008001;
@@ -337,7 +337,7 @@ sub filter {
     }
     else {
         my $xpath = ref $_[0] ? ${$_[0]} : selector_to_xpath($_[0]);
-        @new = grep { $_->matches($xpath) } @{$self->{trees}};        
+        @new = grep { eval { $_->matches($xpath) } } @{$self->{trees}};        
     }
 
     return (ref $self || $self)->new_from_element(\@new, $self);
@@ -651,7 +651,7 @@ Web::Query - Yet another scraping library like jQuery
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
